-- 创建数据库,名为daily_reading
create database daily_reading;

-- 切换daily_reading为当前操作的数据库
use daily_reading;

-- 删除"可能"已经存在的表
drop table if exists user_info;
drop table if exists diary;

-- 用户信息表
create table user_info (
	id char(36),
	wxId varchar(64) comment '微信id',
	token char(36) comment 'token',
	tokenExpires datetime comment 'token过期时间',
	nickName varchar(64) comment '用户昵称',
	favCnt int not null default 0 comment '关注数',
	fansCnt int not null default 0 comment '粉丝数', 
	diaryCnt int not null default 0 comment '总日记数',
	primary key (`id`)
);

-- 日记信息表
create table diary (
  id char(36),
  userId char(36) not null comment '用户ID',
  title varchar(64) not null comment '日记标题',
  publishTime datetime not null comment '发表时间',
  cover varchar(128) comment '封面图片路径',
  content text comment '日记内容',
  audioPath varchar(128) comment '音频文件存储路径',
  audioDuration int comment '音频时长',
  readCnt int not null default 0 comment '阅读数',
  praiseCnt int not null default 0 comment '点赞数',
  primary key (`id`),
  KEY `diary_userId_IDX` (`userId`),
  CONSTRAINT `diary_to_user_FK` FOREIGN KEY (`userId`) REFERENCES `user_info` (`id`) ON DELETE CASCADE ON UPDATE CASCADE
);

-- 添加一些初始测试数据
-- user_info
insert into user_info (id, nickName, favCnt, fansCnt, diaryCnt) values ('u1', 'Bailey', 19, 37, 188);
insert into user_info (id, nickName, favCnt, fansCnt, diaryCnt) values ('u2', '小可爱', 	23, 23, 291);
insert into user_info (id, nickName, favCnt, fansCnt, diaryCnt) values ('u3', '小宝贝', 11, 36, 473);
insert into user_info (id, nickName, favCnt, fansCnt, diaryCnt) values ('u4', '小甜心', 3, 8, 0);

-- diary
insert into diary (id, userId, title, publishTime, cover, content, audioPath, audioDuration, readCnt, praiseCnt) values ('d1', 'u1', '冰雪奇缘', '2020-06-28 19:39:23', 'https://bailey.pinruikm.com/images/miniprogram/dr1.gif', '小国阿伦黛尔因一个魔咒永远地被冰天雪地覆盖，为了寻回夏天，安娜公主和山民克里斯托夫以及他的驯鹿搭档组队出发，展开一段拯救王国的历险。', null, null, 19, 8);
insert into diary (id, userId, title, publishTime, cover, content, audioPath, audioDuration, readCnt, praiseCnt) values ('d2', 'u2', '小王子', '2020-05-03 20:43:37', 'https://bailey.pinruikm.com/images/miniprogram/dr2.jpg', '小王子从自己星球出发前往地球的过程中，所经历的各种历险。作者以小王子的孩子式的眼光，透视出成人的空虚、盲目，愚妄和死板教条，用浅显天真的语言写出了人类的孤独寂寞、没有根基随风流浪的命运。', null, null, 4, 3);
insert into diary (id, userId, title, publishTime, cover, content, audioPath, audioDuration, readCnt, praiseCnt) values ('d3', 'u3', '白雪公主', '2020-04-24 21:34:30', 'https://bailey.pinruikm.com/images/miniprogram/dr3.jpg', '白雪公主受到继母皇后，逃到森林里，遇到七个小矮人的故事。', 'https://bailey.pinruikm.com/images/miniprogram/audio3.mp3', 73, 12, 7);
insert into diary (id, userId, title, publishTime, cover, content, audioPath, audioDuration, readCnt, praiseCnt) values ('d4', 'u1', '青鸟', '2020-04-22 09:23:23', 'https://bailey.pinruikm.com/images/miniprogram/dr4.jpg', '青鸟就是幸bai福的象征。通过他们一路上的经历，象征性地再现了迄今为止，人类为了寻找幸福所经历过的全部苦难', 'https://bailey.pinruikm.com/images/miniprogram/audio4.mp3', 99, 4, 6);