const dbUtil = require('../utils/dbUtil.js');   // 引入dbUtil模块
const uuid = require('uuid');
const TOKEN_EXPIRES = 1000 * 60 * 60;           // TOKEN有效期: 1小时

// 用户登录 
async function login(openId, userInfo) {
    const token = uuid.v1();                                          // 使用uuid作为token
    const tokenExpires = new Date(Date.now() + TOKEN_EXPIRES);        // token失效时间

    // 直接尝试更新 wxId == openId 的用户的token值
    const updateTokenResult = await dbUtil.query('update user_info set token=?, tokenExpires=? where wxId=?', [token, tokenExpires, openId]);

    // 若affectedRows大于0, 则说明有对应用户, 并且第10行已将新的token写入数据库, 直接返回即可
    // 若affectedRows为0则说明无对应用户(新用户), 继续走16行后的流程
    if (updateTokenResult.affectedRows > 0) return token;

    // 将新用户信息及token插入数据库(参看发表日记的代码)
    const fields = ['id', 'wxId', 'nickName', 'token', 'tokenExpires'];
    const params = {
        id: uuid.v1(),
        wxId: openId,
        nickName: userInfo.nickName,
        token,
        tokenExpires
    };
    const sqlAndValues = dbUtil.buildInsert('user_info', fields, params);
    await dbUtil.query(sqlAndValues.sql, sqlAndValues.values);

    return token;
}

// 校验token有效性
// 若有效, 延长token有效期, 并返回匹配的用户ID 
async function checkToken(token) {
    // 查找token值匹配且未过期的用户id
    const validUser = await dbUtil.query('select id from user_info where token=? and tokenExpires>?', [token, new Date()]);

    // 未找到(数据库中不存在匹配的有效token), 直接返回
    if (!validUser.length) return null;

    const userId = validUser[0].id;     // select结果为数组

    // 延长token有效期
    const tokenExpires = new Date(Date.now() + TOKEN_EXPIRES);
    await dbUtil.query('update user_info set tokenExpires = ? where id = ?', [tokenExpires, userId]);

    return userId;
}

module.exports = {
    login,
    checkToken
}