const api = require('../../utils/api');

Page({
  data: {
    canIUse: wx.canIUse('button.open-type.getUserInfo'),    // 用户的使用微信版本是否支持获得用户信息
    logging: false    // 是否正在执行登录操作
  },
  onLoad: function () {
    // 查看"获取用户信息"的权限是否已授权
    wx.getSetting({
      success: (res) => {
        if (res.authSetting['scope.userInfo']) {    // 已授权
          // 取得用户信息
          wx.getUserInfo({
            lang: 'zh_CN',
            success: (res) => {
              this.login(res.userInfo);
            }
          });
        }
      }
    });
  },
  // 授权弹窗
  popAuth: function (e) {
    if (e.detail.userInfo) {   // 用户选择"允许"时, 回调参数e.detail.userInfo将带回用户信息
      this.login(e.detail.userInfo);
    } else {                   // 用户拒绝
      wx.showModal({ 
        title: '提示', 
        content: '请授权之后进入阅读打卡', 
        showCancel: false, 
        confirmText: '返回授权' 
      });
    }
  },
  // 登录
  login: async function (userInfo) {
    if (this.data.logging) return;    // 若正在登录, 直接返回, 避免重复执行
    this.setData({ logging: true });

    try {
      await api.login(userInfo);
      wx.redirectTo({ url: '/pages/index/index' });
    } catch (e) {
      wx.showModal({ title: '提示', content: '登录失败: ' + e.errMsg, showCancel: false });
      this.setData({ logging: false });
    }
  }
})