// 服务器地址
const SERVER_API = 'http://localhost:8000';

// 向服务器发送http/https请求
const request = (url, data) => {
  return new Promise((resolve, reject) => {
    wx.showLoading({ title: '加载数据中...'});
    wx.request({
      url: `${SERVER_API}${url}`,
      method: 'POST',
      data: data || {},
      header: {
        'daily-reading-token': wx.getStorageSync('TOKEN')
      },
      success: (resp) => {
        wx.hideLoading();
        if (resp.statusCode === 200) {
          resolve(resp.data);  
        } else if (resp.statusCode === 403) {
          wx.showToast({ title: resp.data, icon: 'none' });
          wx.navigateTo({ url: '/pages/login/login' });
        } else {
          wx.showToast({ title: '网络请求失败: ' + resp.statusCode, icon: 'none' });
        }
      },
      fail: (err) => {
        wx.showToast({ title: '网络请求失败', icon: 'none' });
        reject(err);
      }
    });
  });
}

// 上传文件
const uploadFile = (url, data, localFilePath, processCallback) => {
  return new Promise((resolve, reject) => {
    wx.showLoading({ title: '文件上传中...'});
    const uploadTask = wx.uploadFile({
      url: `${SERVER_API}${url}`,
      method: 'POST',
      filePath: localFilePath,
      name: 'file',
      formData: data || {},
      header: {
        "Content-Type": "multipart/form-data",
        'daily-reading-token': wx.getStorageSync('TOKEN')
      },
      success: (resp) => {
        wx.hideLoading();
        if (resp.statusCode === 200) {
          resolve(resp.data);  
        } else {
          wx.showToast({ title: '上传文件失败: ' + resp.statusCode, icon: 'none' });
        }
      },
      fail: (err) => {
        wx.showToast({ title: '上传文件失败', icon: 'none' });
        reject(err);
      }
    });
    uploadTask.onProgressUpdate((resp) => {
      if (processCallback) processCallback(resp, uploadTask);
    })
  });
}

// 向服务器发送登录请求
const login = (userInfo) => {
  return new Promise((resolve, reject) => {
    wx.login({
      success: (res) => {
        if (!res.code) return reject(res.errMsg);
        wx.request({
          url: `${SERVER_API}/login`,
          method: 'POST',
          data: {
            code: res.code,
            userInfo
          },
          success: (resp) => {
            if (resp.statusCode === 200 && resp.data.token) {
              wx.setStorageSync('TOKEN', resp.data.token);
              resolve();  
            } else {
              reject({errMsg: resp.data});
            }
          },
          fail: (err) => {
            wx.showToast({ title: '登录失败', icon: 'none' });
            reject(err);
          }
        });
      },
      fail: (err) => {
        wx.showToast({ title: '登录失败', icon: 'none' });
        reject(err);
      }
    })
  });
}

module.exports = {
  SERVER_PATH: SERVER_API + '/',
  request,
  uploadFile,
  login
}